Module path

Module path 

Path types.

Structs

Path
A qualified path like java.util.List or just List.
PathSegment
A segment of a path, optionally with type arguments.
TypeArguments
Type arguments: <String, Integer>.
Wildcard
A wildcard type argument: ? extends T or ? super T.

Enums

TypeArgument
A type argument, which can be a concrete type or a wildcard.
WildcardBound
The bound of a wildcard type argument.