pub struct ClassOrInterfaceType {
pub path: Path,
pub annotations_prefix: Vec<Annotation>,
}Expand description
A class or interface type with optional type arguments.
Fields
path: PathFor a simple type like List, this is the name with optional type args.
For a qualified type like Map.Entry, this contains both segments.
annotations_prefix: Vec<Annotation>Implementations