macro_rules! peek_ident {
($stream:expr) => { ... };
}Expand description
Peek at the next token and check if it is an identifier.
macro_rules! peek_ident {
($stream:expr) => { ... };
}Peek at the next token and check if it is an identifier.