ClassOrInterfaceType

Struct ClassOrInterfaceType 

pub struct ClassOrInterfaceType {
    pub path: Path,
    pub annotations_prefix: Vec<Annotation>,
}
A class or interface type with optional type arguments.

Fields

path: Path

For a simple type like List, this is the name with optional type args. For a qualified type like Map.Entry, this contains both segments.

annotations_prefix: Vec<Annotation>

Implementations

Source

impl ClassOrInterfaceType

pub fn span(&self) -> Span

pub fn name(&self) -> &Ident

pub fn type_args(&self) -> Option<&TypeArguments>